# unity-sds-apgs-client
Service for application package generation

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.0
- Package version: 1.0.0
- Generator version: 7.7.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python 3.7+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import unity_sds_apgs_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import unity_sds_apgs_client
```

### Tests

Execute `pytest` to run the tests.

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import unity_sds_apgs_client
from unity_sds_apgs_client.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://api.dev.mdps.mcp.nasa.gov
# See configuration.py for a list of all supported configuration parameters.
configuration = unity_sds_apgs_client.Configuration(
    host = "http://api.dev.mdps.mcp.nasa.gov"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: bearerAuth
configuration = unity_sds_apgs_client.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)


# Enter a context with an instance of the API client
with unity_sds_apgs_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = unity_sds_apgs_client.DefaultApi(api_client)
    clone_url = 'clone_url_example' # str |

    try:
        # Begins the MCP Clone process
        api_response = api_instance.ads_acb_mcp_clone_get(clone_url)
        print("The response of DefaultApi->ads_acb_mcp_clone_get:\n")
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling DefaultApi->ads_acb_mcp_clone_get: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://api.dev.mdps.mcp.nasa.gov*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*DefaultApi* | [**ads_acb_mcp_clone_get**](docs/DefaultApi.md#ads_acb_mcp_clone_get) | **GET** /ads-acb/mcp-clone | Begins the MCP Clone process


## Documentation For Models

 - [AdsAcbMcpCloneGet200Response](docs/AdsAcbMcpCloneGet200Response.md)


<a id="documentation-for-authorization"></a>
## Documentation For Authorization


Authentication schemes defined for the API:
<a id="bearerAuth"></a>
### bearerAuth

- **Type**: Bearer authentication


## Author
